# open-firefox-urls-chrome

Utility to get URLs currently open in Firefox and open them in Chrome


## Install
    pip3 install open-firefox-urls-chrome
    
    
## Using from command line
    open-firefox-urls-chrome

## Credit
Python for getting firefox urls taken from https://github.com/luismsgomes/get-firefox-urls


## License
This software is licensed under the MIT license.
https://opensource.org/licenses/MIT
